@@ -802,7 +802,7 @@ struct srec_data * read_srec(const char *fname)
 
 	f = fopen(fname, "r");
 	if (f == NULL) {
-		printf("'%s' not readable.\n", fname);
+		printf("'%s' not readable: %s.\n", fname, strerror(errno));
 		return NULL;
 	}
 
